"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ControlledSelect = exports.Select = exports.Options = void 0;
/* eslint-disable max-lines-per-function */
var bottom_sheet_1 = require("@gorhom/bottom-sheet");
var flash_list_1 = require("@shopify/flash-list");
var nativewind_1 = require("nativewind");
var React = __importStar(require("react"));
var react_hook_form_1 = require("react-hook-form");
var react_native_1 = require("react-native");
var react_native_2 = require("react-native");
var react_native_svg_1 = __importStar(require("react-native-svg"));
var tailwind_variants_1 = require("tailwind-variants");
var colors_1 = __importDefault(require("../../components/ui/colors"));
var icons_1 = require("../../components/ui/icons");
var modal_1 = require("./modal");
var modal_2 = require("./modal");
var text_1 = require("./text");
var selectTv = (0, tailwind_variants_1.tv)({
    slots: {
        container: 'mb-4',
        label: 'text-grey-100 mb-1 text-lg dark:text-neutral-100',
        input: 'border-grey-50 mt-0 flex-row items-center justify-center rounded-xl border-[0.5px] p-3  dark:border-neutral-500 dark:bg-neutral-800',
        inputValue: 'dark:text-neutral-100',
    },
    variants: {
        focused: {
            true: {
                input: 'border-neutral-600',
            },
        },
        error: {
            true: {
                input: 'border-danger-600',
                label: 'text-danger-600 dark:text-danger-600',
                inputValue: 'text-danger-600',
            },
        },
        disabled: {
            true: {
                input: 'bg-neutral-200',
            },
        },
    },
    defaultVariants: {
        error: false,
        disabled: false,
    },
});
var List = react_native_1.Platform.OS === 'web' ? flash_list_1.FlashList : bottom_sheet_1.BottomSheetFlatList;
function keyExtractor(item) {
    return "select-item-".concat(item.value);
}
exports.Options = React.forwardRef(function (_a, ref) {
    var options = _a.options, onSelect = _a.onSelect, value = _a.value, testID = _a.testID;
    var height = options.length * 70 + 100;
    var snapPoints = React.useMemo(function () { return [height]; }, [height]);
    var colorScheme = (0, nativewind_1.useColorScheme)().colorScheme;
    var isDark = colorScheme === 'dark';
    var renderSelectItem = React.useCallback(function (_a) {
        var item = _a.item;
        return (<Option key={"select-item-".concat(item.value)} label={item.label} selected={value === item.value} onPress={function () { return onSelect(item); }} testID={testID ? "".concat(testID, "-item-").concat(item.value) : undefined}/>);
    }, [onSelect, value, testID]);
    return (<modal_2.Modal ref={ref} index={0} snapPoints={snapPoints} backgroundStyle={{
            backgroundColor: isDark ? colors_1.default.neutral[800] : colors_1.default.white,
        }}>
        <List data={options} keyExtractor={keyExtractor} renderItem={renderSelectItem} testID={testID ? "".concat(testID, "-modal") : undefined} estimatedItemSize={52}/>
      </modal_2.Modal>);
});
var Option = React.memo(function (_a) {
    var label = _a.label, _b = _a.selected, selected = _b === void 0 ? false : _b, props = __rest(_a, ["label", "selected"]);
    return (<react_native_2.Pressable className="flex-row items-center border-b border-neutral-300 bg-white px-3 py-2 dark:border-neutral-700 dark:bg-neutral-800" {...props}>
        <text_1.Text className="flex-1 dark:text-neutral-100 ">{label}</text_1.Text>
        {selected && <Check />}
      </react_native_2.Pressable>);
});
var Select = function (props) {
    var label = props.label, value = props.value, error = props.error, _a = props.options, options = _a === void 0 ? [] : _a, _b = props.placeholder, placeholder = _b === void 0 ? 'select...' : _b, _c = props.disabled, disabled = _c === void 0 ? false : _c, onSelect = props.onSelect, testID = props.testID;
    var modal = (0, modal_1.useModal)();
    var onSelectOption = React.useCallback(function (option) {
        onSelect === null || onSelect === void 0 ? void 0 : onSelect(option.value);
        modal.dismiss();
    }, [modal, onSelect]);
    var styles = React.useMemo(function () {
        return selectTv({
            error: Boolean(error),
            disabled: disabled,
        });
    }, [error, disabled]);
    var textValue = React.useMemo(function () {
        var _a, _b, _c;
        return value !== undefined
            ? ((_c = (_b = (_a = options === null || options === void 0 ? void 0 : options.filter(function (t) { return t.value === value; })) === null || _a === void 0 ? void 0 : _a[0]) === null || _b === void 0 ? void 0 : _b.label) !== null && _c !== void 0 ? _c : placeholder)
            : placeholder;
    }, [value, options, placeholder]);
    return (<>
      <react_native_1.View className={styles.container()}>
        {label && (<text_1.Text testID={testID ? "".concat(testID, "-label") : undefined} className={styles.label()}>
            {label}
          </text_1.Text>)}
        <react_native_2.Pressable className={styles.input()} disabled={disabled} onPress={modal.present} testID={testID ? "".concat(testID, "-trigger") : undefined}>
          <react_native_1.View className="flex-1">
            <text_1.Text className={styles.inputValue()}>{textValue}</text_1.Text>
          </react_native_1.View>
          <icons_1.CaretDown />
        </react_native_2.Pressable>
        {error && (<text_1.Text testID={"".concat(testID, "-error")} className="text-sm text-danger-300 dark:text-danger-600">
            {error}
          </text_1.Text>)}
      </react_native_1.View>
      <exports.Options testID={testID} ref={modal.ref} options={options} onSelect={onSelectOption}/>
    </>);
};
exports.Select = Select;
// only used with react-hook-form
function ControlledSelect(props) {
    var _a;
    var name = props.name, control = props.control, rules = props.rules, onNSelect = props.onSelect, selectProps = __rest(props, ["name", "control", "rules", "onSelect"]);
    var _b = (0, react_hook_form_1.useController)({ control: control, name: name, rules: rules }), field = _b.field, fieldState = _b.fieldState;
    var onSelect = React.useCallback(function (value) {
        field.onChange(value);
        onNSelect === null || onNSelect === void 0 ? void 0 : onNSelect(value);
    }, [field, onNSelect]);
    return (<exports.Select onSelect={onSelect} value={field.value} error={(_a = fieldState.error) === null || _a === void 0 ? void 0 : _a.message} {...selectProps}/>);
}
exports.ControlledSelect = ControlledSelect;
var Check = function (_a) {
    var props = __rest(_a, []);
    return (<react_native_svg_1.default width={25} height={24} fill="none" viewBox="0 0 25 24" {...props} className="stroke-black dark:stroke-white">
    <react_native_svg_1.Path d="m20.256 6.75-10.5 10.5L4.506 12" strokeWidth={2.438} strokeLinecap="round" strokeLinejoin="round"/>
  </react_native_svg_1.default>);
};
//# sourceMappingURL=select.js.map